VectorVein agent runtime, SDK, CLI, tools, memory, prompt, and workspace APIs.
This crate exposes a stable Rust library surface for building and running agent workflows with built-in tool dispatch and vv-llm backed chat clients.
Re-exports
pub use agent::Agent;pub use agent::InstructionProvider;pub use agent::ToolUseBehavior;pub use app_server::AgentResolutionRequest;pub use app_server::AppServerHost;pub use app_server::AppServerHostError;pub use app_server::DefaultAppServerHost;pub use app_server::RunConfigResolutionRequest;pub use approval::ApprovalBroker;pub use approval::ApprovalError;pub use approval::ApprovalFuture;pub use approval::ApprovalProvider;pub use approval::ApprovalRequest;pub use budget::BudgetDimension;pub use budget::BudgetEnforcementBoundary;pub use budget::BudgetExhaustion;pub use budget::BudgetExhaustionReason;pub use budget::BudgetUsageSnapshot;pub use budget::HostCost;pub use budget::HostCostMeter;pub use budget::RunBudgetLimits;pub use budget::RunBudgetLimitsBuilder;pub use budget::MAX_WIRE_INTEGER;pub use checkpoint::canonical_json_bytes;pub use checkpoint::event_payload_digest;pub use checkpoint::model_request_digest;pub use checkpoint::normalize_run_definition;pub use checkpoint::operation_request_digest;pub use checkpoint::redact_run_definition;pub use checkpoint::run_definition_digest;pub use checkpoint::tool_request_digest;pub use checkpoint::validate_extension_namespace;pub use checkpoint::validate_run_definition;pub use checkpoint::AmbiguousModelPolicy;pub use checkpoint::AmbiguousToolPolicy;pub use checkpoint::AppendOnceResult;pub use checkpoint::CheckpointConfig;pub use checkpoint::CheckpointError;pub use checkpoint::CheckpointExtension;pub use checkpoint::CheckpointStatus;pub use checkpoint::ClaimMode;pub use checkpoint::EventCursor;pub use checkpoint::IdempotentRunEventStore;pub use checkpoint::InMemoryRunEventStore;pub use checkpoint::OperationKind;pub use checkpoint::OperationState;pub use checkpoint::ReconciliationDecision;pub use checkpoint::ReconciliationDecisionKind;pub use checkpoint::ReconciliationError;pub use checkpoint::ReconciliationProvider;pub use checkpoint::ResumeObservation;pub use checkpoint::ResumePolicy;pub use checkpoint::ToolIdempotency;pub use config::apply_resolved_model_limits;pub use config::build_vv_llm_from_local_settings;pub use config::build_vv_llm_settings;pub use config::decode_api_key;pub use config::load_llm_settings_from_file;pub use config::load_memory_summary_defaults_from_file;pub use config::resolve_model_endpoint;pub use config::ConfigError;pub use config::EndpointConfig;pub use config::EndpointOption;pub use config::MemorySummaryDefaults;pub use config::ResolvedModelConfig;pub use context::RunContext;pub use context::ToolCallContext;pub use context_providers::assemble_context_fragments;pub use context_providers::collect_context_fragments;pub use context_providers::ContextBundle;pub use context_providers::ContextError;pub use context_providers::ContextFragment;pub use context_providers::ContextProvider;pub use context_providers::ContextRequest;pub use context_providers::ContextSection;pub use event_store::EventStoreError;pub use event_store::JsonlRunEventStore;pub use event_store::RunEventIter;pub use event_store::RunEventReplayQuery;pub use event_store::RunEventStore;pub use events::AgentErrorPayload;pub use events::EventId;pub use events::RunEvent;pub use events::RunEventPayload;pub use events::RunEventVersion;pub use events::ToolStatus;pub use execution_mode::ExecutionMode;pub use guardrails::GuardrailOutcome;pub use guardrails::InputGuardrail;pub use guardrails::OutputGuardrail;pub use handoffs::handoff;pub use handoffs::Handoff;pub use interactive::create_interactive_session;pub use interactive::InteractiveAgentClient;pub use interactive::InteractiveSession;pub use interactive::InteractiveSessionError;pub use interactive::InteractiveSessionEvent;pub use interactive::InteractiveSessionOptions;pub use interactive::InteractiveSessionState;pub use llm::EndpointTarget;pub use llm::LlmClient;pub use llm::LlmError;pub use llm::LlmRequest;pub use llm::LlmStreamCallback;pub use llm::ScriptStep;pub use llm::ScriptStepCallback;pub use llm::ScriptedLlmClient;pub use llm::VvLlmClient;pub use memory::sanitize_for_resume;pub use memory::CompactionExhaustedError;pub use memory::LocalSummary;pub use memory::MemoryError;pub use memory::MemoryFuture;pub use memory::MemoryManager;pub use memory::MemoryManagerConfig;pub use memory::MemoryProvider;pub use memory::MemoryProviderResult;pub use memory::MemorySaveRequest;pub use memory::MemorySaveResult;pub use memory::MemorySearchRequest;pub use memory::MemorySearchResult;pub use memory::SessionMemory;pub use memory::SessionMemoryConfig;pub use memory::SessionMemoryEntry;pub use memory::SessionMemoryState;pub use memory::SummaryCallback;pub use model::ModelError;pub use model::ModelProvider;pub use model::ModelRef;pub use model::ScriptedModelProvider;pub use model::VvLlmModelProvider;pub use model_settings::ModelSettings;pub use model_settings::ResponseFormat;pub use model_settings::RetryPolicy;pub use model_settings::RetrySettings;pub use model_settings::ToolChoice;pub use result::ApprovalSnapshot;pub use result::FinalOutputError;pub use result::RunResult;pub use result::RunState;pub use run_config::RunConfig;pub use run_config::ToolRegistryFactory;pub use run_handle::RunHandle;pub use run_handle::RunHandleState;pub use run_handle::RunHandleStatus;pub use runner::NormalizedInput;pub use runner::RunEventStream;pub use runner::Runner;pub use runtime::backends::run_checkpointed_cycle;pub use runtime::backends::CapabilityRef;pub use runtime::backends::CycleDispatchResult;pub use runtime::backends::CycleDispatcher;pub use runtime::backends::DistributedBackend;pub use runtime::backends::DistributedCapabilities;pub use runtime::backends::DistributedCapabilityError;pub use runtime::backends::DistributedCapabilityRegistry;pub use runtime::backends::DistributedCycleWorker;pub use runtime::backends::DistributedRunEnvelope;pub use runtime::backends::DistributedToolPolicy;pub use runtime::backends::InlineBackend;pub use runtime::backends::ResolvedDistributedCapabilities;pub use runtime::backends::RuntimeExecutionBackend;pub use runtime::backends::RuntimeRecipe;pub use runtime::backends::ThreadBackend;pub use runtime::backends::ToolsetRef;pub use runtime::background_sessions::background_session_manager;pub use runtime::background_sessions::BackgroundSessionAdoptOptions;pub use runtime::background_sessions::BackgroundSessionListener;pub use runtime::background_sessions::BackgroundSessionManager;pub use runtime::background_sessions::BackgroundSessionStartOptions;pub use runtime::background_sessions::BackgroundSessionSubscription;pub use runtime::checkpoint_codec_v2::checkpoint_v2_from_json;pub use runtime::checkpoint_codec_v2::checkpoint_v2_to_json;pub use runtime::checkpoint_codec_v2::decode_checkpoint;pub use runtime::checkpoint_codec_v2::decode_checkpoint_bytes;pub use runtime::checkpoint_codec_v2::encode_checkpoint_v1;pub use runtime::checkpoint_codec_v2::migrate_terminal_v1;pub use runtime::checkpoint_codec_v2::DecodedCheckpoint;pub use runtime::shell::build_shell_invocation;pub use runtime::shell::prepare_shell_execution;pub use runtime::shell::resolve_shell_invocation;pub use runtime::shell::PreparedShellCommand;pub use runtime::shell::ShellInvocation;pub use runtime::state::Checkpoint;pub use runtime::state::InMemoryStateStore;pub use runtime::state::StateStore;pub use runtime::state_v2::CheckpointStoreV2;pub use runtime::state_v2::CheckpointV2;pub use runtime::state_v2::EventOutboxEntry;pub use runtime::state_v2::ExtensionStateEntry;pub use runtime::state_v2::OperationError;pub use runtime::state_v2::OperationJournalEntry;pub use runtime::stores::memory_v2::InMemoryCheckpointStoreV2;pub use runtime::stores::redis::RedisStateStore;pub use runtime::stores::redis_v2::RedisCheckpointStoreV2;pub use runtime::stores::sqlite::SqliteStateStore;pub use runtime::stores::sqlite_v2::SqliteCheckpointStoreV2;pub use runtime::sub_task_manager::ManagedSubTask;pub use runtime::sub_task_manager::ManagedSubTaskSnapshot;pub use runtime::sub_task_manager::SubTaskManager;pub use runtime::sub_task_manager::SubTaskSessionAttachment;pub use runtime::sub_task_manager::SubTaskTurnSnapshot;pub use runtime::_register_sub_agent_session;pub use runtime::_unregister_sub_agent_session;pub use runtime::continue_sub_agent_session;pub use runtime::get_sub_agent_session;pub use runtime::register_sub_agent_session;pub use runtime::steer_sub_agent_session;pub use runtime::sub_agent_session_registry;pub use runtime::subscribe_sub_agent_session;pub use runtime::unregister_sub_agent_session;pub use runtime::AfterLlmEvent;pub use runtime::AfterToolCallEvent;pub use runtime::AgentRuntime;pub use runtime::BeforeCycleMessageProvider;pub use runtime::BeforeLlmEvent;pub use runtime::BeforeLlmPatch;pub use runtime::BeforeMemoryCompactEvent;pub use runtime::BeforeToolCallEvent;pub use runtime::BeforeToolCallPatch;pub use runtime::CancellationToken;pub use runtime::CancelledError;pub use runtime::CycleRunRequest;pub use runtime::CycleRunner;pub use runtime::ExecutionContext;pub use runtime::InterruptionMessageProvider;pub use runtime::RuntimeEventHandler;pub use runtime::RuntimeHook;pub use runtime::RuntimeHookManager;pub use runtime::RuntimeRunControls;pub use runtime::StreamCallback;pub use runtime::SubAgentSession;pub use runtime::SubAgentSessionListener;pub use runtime::SubAgentSessionRegistry;pub use runtime::SubAgentSessionUnsubscribe;pub use runtime::ToolCallRunner;pub use runtime::ToolRunOutcome;pub use runtime::ToolRunRequest;pub use runtime::MAX_PROMPT_TOO_LONG_RETRIES;pub use runtime::MAX_PTL_RETRIES;pub use sessions::session_store_conformance;pub use sessions::MemorySession;pub use sessions::MemorySessionStore;pub use sessions::RedisSessionStore;pub use sessions::Session;pub use sessions::SessionItem;pub use sessions::SessionStore;pub use sessions::SqliteSessionStore;pub use tools::build_default_registry;pub use tools::dispatch_tool_call;pub use tools::AgentTool;pub use tools::AgentToolBuilder;pub use tools::ApprovalDecision;pub use tools::ApprovalPolicy;pub use tools::ApprovalPredicate;pub use tools::ApprovalRequirement;pub use tools::BackgroundAgentTask;pub use tools::BackgroundAgentTaskBuilder;pub use tools::BackgroundAgentTaskHandle;pub use tools::BackgroundAgentTaskSnapshot;pub use tools::FunctionTool;pub use tools::StaticTool;pub use tools::Tool;pub use tools::ToolApprovalRule;pub use tools::ToolContext;pub use tools::ToolError;pub use tools::ToolExecutor;pub use tools::ToolExposure;pub use tools::ToolFuture;pub use tools::ToolHandler;pub use tools::ToolNotFoundError;pub use tools::ToolOrchestrator;pub use tools::ToolOutput;pub use tools::ToolPolicy;pub use tools::ToolRegistry;pub use tools::ToolRunContext;pub use tools::ToolRunOptions;pub use tools::ToolSpec;pub use tools::ToolSpecContext;pub use tools::ToolSpecExecutor;pub use tools::ToolSpecKind;pub use tracing::JsonlTraceExporter;pub use tracing::Span;pub use tracing::TraceSink;pub use types::AgentResult;pub use types::AgentStatus;pub use types::AgentTask;pub use types::CacheUsage;pub use types::CacheUsageStatus;pub use types::CompletionReason;pub use types::CycleRecord;pub use types::CycleStatus;pub use types::LLMResponse;pub use types::Message;pub use types::MessageRole;pub use types::NoToolPolicy;pub use types::SubAgentConfig;pub use types::SubAgentConfigValidationError;pub use types::SubTaskOutcome;pub use types::SubTaskRequest;pub use types::TaskTokenUsage;pub use types::TokenUsage;pub use types::ToolCall;pub use types::ToolDirective;pub use types::ToolExecutionResult;pub use types::ToolResultStatus;pub use types::UsageSource;pub use types::INVALID_SUB_AGENT_MODEL_CODE;pub use types::INVALID_SUB_AGENT_MODEL_MESSAGE;pub use types::INVALID_SUB_AGENT_SYSTEM_PROMPT_CODE;pub use types::INVALID_SUB_AGENT_SYSTEM_PROMPT_MESSAGE;pub use workspace::validate_portable_exclude_pattern;pub use workspace::DiscoveryFilteredWorkspaceBackend;pub use workspace::FileInfo;pub use workspace::LocalWorkspaceBackend;pub use workspace::MemoryWorkspaceBackend;pub use workspace::PortableRegexError;pub use workspace::S3WorkspaceBackend;pub use workspace::S3WorkspaceConfig;pub use workspace::WorkspaceBackend;pub use workspace::INVALID_EXCLUDE_FILES_PATTERN_CODE;pub use workspace::INVALID_EXCLUDE_FILES_PATTERN_MESSAGE;
Modules
- agent
- app_
server - approval
- budget
- checkpoint
- Public building blocks for the opt-in durable checkpoint v2 protocol.
- cli
- config
- constants
- context
- context_
providers - event_
store - events
- execution_
mode - guardrails
- handoffs
- integrations
- interactive
- Embedded, stateful sessions built on the public runner primitives.
- llm
- memory
- model
- model_
settings - prompt
- result
- run_
config - run_
handle - runner
- runtime
- sessions
- skills
- tools
- tracing
- types
- workspace