pub struct TurnCompletedParams {Show 14 fields
pub thread_id: String,
pub turn_id: String,
pub run_id: Option<String>,
pub status: TurnStatus,
pub final_output: Option<String>,
pub completion_reason: Option<String>,
pub completion_tool_name: Option<String>,
pub partial_output: Option<String>,
pub error: Option<String>,
pub token_usage: Option<AppTokenUsage>,
pub budget_usage: Option<BTreeMap<String, Value>>,
pub budget_exhaustion: Option<BTreeMap<String, Value>>,
pub checkpoint: Option<CheckpointSummary>,
pub interruption: Option<InterruptionSummary>,
}Fields
thread_id: Stringturn_id: Stringrun_id: Option<String>status: TurnStatusfinal_output: Option<String>completion_reason: Option<String>completion_tool_name: Option<String>partial_output: Option<String>error: Option<String>token_usage: Option<AppTokenUsage>budget_usage: Option<BTreeMap<String, Value>>budget_exhaustion: Option<BTreeMap<String, Value>>checkpoint: Option<CheckpointSummary>interruption: Option<InterruptionSummary>Trait Implementations
Sourceimpl Clone for TurnCompletedParams
impl Clone for TurnCompletedParams
Sourcefn clone(&self) -> TurnCompletedParams
fn clone(&self) -> TurnCompletedParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TurnCompletedParams
impl Debug for TurnCompletedParams
Sourceimpl<'de> Deserialize<'de> for TurnCompletedParams
impl<'de> Deserialize<'de> for TurnCompletedParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TurnCompletedParams
impl JsonSchema for TurnCompletedParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TurnCompletedParams
impl PartialEq for TurnCompletedParams
Sourceimpl Serialize for TurnCompletedParams
impl Serialize for TurnCompletedParams
impl StructuralPartialEq for TurnCompletedParams
Sourceimpl TS for TurnCompletedParams
impl TS for TurnCompletedParams
Sourcetype WithoutGenerics = TurnCompletedParams
type WithoutGenerics = TurnCompletedParams
If this type does not have generic parameters, then
WithoutGenerics should just be Self.
If the type does have generic parameters, then all generic parameters must be replaced with
a dummy type, e.g ts_rs::Dummy or ().
The only requirement for these dummy types is that EXPORT_TO must be None. Read moreSourcetype OptionInnerType = TurnCompletedParams
type OptionInnerType = TurnCompletedParams
If the implementing type is
std::option::Option<T>, then this associated type is set to T.
All other implementations of TS should set this type to Self instead.Sourcefn decl_concrete() -> String
fn decl_concrete() -> String
Declaration of this type using the supplied generic arguments.
The resulting TypeScript definition will not be generic. For that, see
TS::decl().
If this type is not generic, then this function is equivalent to TS::decl().Sourcefn decl() -> String
fn decl() -> String
Declaration of this type, e.g.
type User = { user_id: number, ... }.
This function will panic if the type has no declaration. Read moreSourcefn inline() -> String
fn inline() -> String
Formats this types definition in TypeScript, e.g
{ user_id: number }.
This function will panic if the type cannot be inlined.Sourcefn inline_flattened() -> String
fn inline_flattened() -> String
Flatten a type declaration.
This function will panic if the type cannot be flattened.
This function will panic if the type cannot be flattened.
Sourcefn visit_generics(v: &mut impl TypeVisitor)where
Self: 'static,
fn visit_generics(v: &mut impl TypeVisitor)where
Self: 'static,
Iterates over all type parameters of this type.
Sourcefn output_path() -> Option<PathBuf>
fn output_path() -> Option<PathBuf>
Returns the output path to where
The returned path does not include the base directory from
T should be exported.The returned path does not include the base directory from
TS_RS_EXPORT_DIR. Read moreSourcefn visit_dependencies(v: &mut impl TypeVisitor)where
Self: 'static,
fn visit_dependencies(v: &mut impl TypeVisitor)where
Self: 'static,
Iterates over all dependency of this type.
Sourcefn docs() -> Option<String>
fn docs() -> Option<String>
JSDoc comment to describe this type in TypeScript - when
TS is derived, docs are
automatically read from your doc comments or #[doc = ".."] attributesSourcefn dependencies() -> Vec<Dependency>where
Self: 'static,
fn dependencies() -> Vec<Dependency>where
Self: 'static,
Resolves all dependencies of this type recursively.
Sourcefn export() -> Result<(), ExportError>where
Self: 'static,
fn export() -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem.
To export this type together with all of its dependencies, use
TS::export_all. Read moreSourcefn export_all() -> Result<(), ExportError>where
Self: 'static,
fn export_all() -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem, together with all of its dependencies.
To export only this type, without its dependencies, use
To export only this type, without its dependencies, use
TS::export. Read moreSourcefn export_all_to(out_dir: impl AsRef<Path>) -> Result<(), ExportError>where
Self: 'static,
fn export_all_to(out_dir: impl AsRef<Path>) -> Result<(), ExportError>where
Self: 'static,
Manually export this type into the given directory, together with all of its dependencies.
To export only this type, without its dependencies, use
To export only this type, without its dependencies, use
TS::export. Read moreSourcefn export_to_string() -> Result<String, ExportError>where
Self: 'static,
fn export_to_string() -> Result<String, ExportError>where
Self: 'static,