pub struct PromptBundle {
pub sections: Vec<PromptSection>,
pub stable_hash: String,
}Fields
sections: Vec<PromptSection>stable_hash: StringImplementations
Sourceimpl PromptBundle
impl PromptBundle
pub fn new(sections: Vec<PromptSection>) -> Result<Self, String>
pub fn from_instruction_text(text: impl Into<String>) -> Result<Self, String>
Sourcepub fn with_session_memory_context(
&self,
session_memory_context: impl AsRef<str>,
) -> Result<Self, String>
pub fn with_session_memory_context( &self, session_memory_context: impl AsRef<str>, ) -> Result<Self, String>
Freeze persisted Session Memory into the resolved bundle for one run.
A bundle already containing the section is a frozen checkpoint/run bundle, so it must be reused exactly rather than refreshed.
pub fn flatten(&self) -> String
pub fn validate(&self) -> Result<(), String>
pub fn to_value(&self) -> Value
pub fn from_value(value: &Value) -> Result<Self, String>