pub struct EventOutboxEntry {
pub event_id: String,
pub payload_digest: String,
pub state: String,
pub event: Value,
pub cursor: Option<Value>,
}Fields
event_id: Stringpayload_digest: Stringstate: Stringevent: Valuecursor: Option<Value>Implementations
Sourceimpl EventOutboxEntry
impl EventOutboxEntry
pub fn validate(&self) -> CheckpointResult<()>
Sourcepub fn verify_payload(&self) -> CheckpointResult<()>
pub fn verify_payload(&self) -> CheckpointResult<()>
Verify the identity before delivering an outbox entry. A codec read intentionally only validates the wire shape so older producers with a deferred receipt can still be inspected and migrated explicitly.
pub fn pending( event_id: impl Into<String>, event: Value, ) -> CheckpointResult<Self>
pub fn to_value(&self) -> Value
pub fn from_value(value: &Value) -> CheckpointResult<Self>